@@ -3,16 +3,29 @@ from __future__ import division
 
 __author__ = 'jerryzhujian@gmail.com'
 
-__doc__ = """An enhancement to pandas module.
-
+__doc__ = """
+An enhancement to pandas module.
 This is kungfu, with monkey-patched common methods to (Data)Frame and Series in pandas.
-Want pandas functions index?  http://pandas.pydata.org/pandas-docs/dev/genindex.html
+=============================================
+jerryzhujian9_at_gmail.com
+Tested under python 2.7
+To see your python version
+in terminal: python -V
+or in python: import sys; print (sys.version)
+=============================================
+Install:
+https://pypi.python.org/pypi/kungfu
+pip install kungfu
+The above command will auto take care of the following requirements
+Requires pandas 0.12.0 (tested 0.12.0-2) which will also install numpy etc
+Requires openpyxl 1.5.8 (version 1.6.1 or higher, but lower than 2.0.0 may also work, but not tested)
+(pip install pandas==0.12.0; pip install openpyxl==1.5.8)
+
 
 Usage:
-1) import
-from kungfu import *
+Want pandas functions index?  http://pandas.pydata.org/pandas-docs/dev/genindex.html
 
-2) call methods
+Call methods
 All the monkey-patched methods use UpperCase names; the original ones use lower_case names.
 Generally all of the calling (monkey-patched or not) returns something and the original frame or series remains unchanged.
 If user wants the original frame or series to be changed, assign the returns back.
